pub struct MatrixClient { /* private fields */ }
Matrix client type.

Implementations

source

impl MatrixClient

source

pub async fn new( homeserver_url: String, private_key: PrivateKey ) -> MatrixClient

Create a new instance of MatrixClient.

source

pub fn set_sync_token(&mut self, sync_token: String)

Set sync token based on the last sync.

source

pub fn get_sync_token(&self) -> String

Return the last known sync token.

source

pub fn private_key(&self) -> PrivateKey

Return a copy of the private key.

source

pub async fn init(&self) -> Result<(), TransportError>

Initialize the client by logging into the matrix home server.

source

pub async fn populate_services_addresses( &mut self, service_registry_proxy: ServiceRegistryProxy<Http> )

Populate services addresses based on on-chain updates to the service registry.

source

pub async fn get_new_messages(&mut self) -> Result<Vec<IncomingMessage>, Error>

Sync and retrieve any new messages received on the home server.

source

pub fn address_metadata(&self) -> AddressMetadata

Construct the address metadata of the current account.

source

pub fn make_user_id(&self, address: &H160) -> String

Return’s the matrix user ID.

source

pub async fn send( &self, message: OutgoingMessage, receiver_metadata: AddressMetadata ) -> Result<(), TransportError>

Send message to the matrix home server.

source

pub async fn broadcast( &self, data: String, device_id: DeviceIdOrAllDevices ) -> Result<(), TransportError>

Broadcast message to all known service addresses.