Struct raiden_rs::raiden_network_transport::matrix::MatrixService
source · pub struct MatrixService { /* private fields */ }Expand description
Matrix service which is responsible for mediating between queues and the matrix client.
Implementations
sourceimpl MatrixService
impl MatrixService
sourcepub fn new(
config: TransportConfig,
client: MatrixClient,
matrix_storage: MatrixStorage
) -> (MatrixService, UnboundedSender<TransportServiceMessage>)
pub fn new( config: TransportConfig, client: MatrixClient, matrix_storage: MatrixStorage ) -> (MatrixService, UnboundedSender<TransportServiceMessage>)
Creates a new instance of MatrixService.
sourcepub fn init_from_storage(&mut self) -> Result<(), String>
pub fn init_from_storage(&mut self) -> Result<(), String>
Initialize the service from storage.
sourcepub async fn run(self, message_handler: MessageHandler)
pub async fn run(self, message_handler: MessageHandler)
Loops forever, where every iteration in the loop decides whether to process incoming messages, send out outgoing messages or broadcast specific messages to the service providers.