Struct raiden_rs::raiden_state_machine::storage::StateStorage

source ·
pub struct StateStorage { /* private fields */ }
Available on crate feature storage only.
Storage interface for the chain state.

Implementations

source

impl StateStorage

source

pub fn new(conn: Connection) -> StateStorage

Create an instance of StateStorage.

source

pub fn setup_database(&self) -> Result<(), StorageError>

Create tables if not already created.

source

pub fn store_snapshot( &self, state: ChainState, state_change_id: Option<StorageID> ) -> Result<(), StorageError>

Store chain state snapshot.

source

pub fn state_changes(&self) -> Result<Vec<StateChangeRecord>, StorageError>

Return all state changes.

source

pub fn store_state_change( &self, state_change: StateChange ) -> Result<StorageID, StorageError>

Store a state change.

source

pub fn store_events( &self, state_change_id: StorageID, events: Vec<Event> ) -> Result<(), StorageError>

Store a list of events.

source

pub fn get_snapshot_before_state_change( &self, state_change_id: StorageID ) -> Result<SnapshotRecord, StorageError>

Get the last snapshot prior to a specific state change identifier.

source

pub fn get_state_changes_in_range( &self, start_state_change: StorageID, end_state_change: StorageID ) -> Result<Vec<StateChangeRecord>, StorageError>

Get the list of state changes in range of ULIDs.

source

pub fn get_latest_state_change_by_data_field( &self, criteria: Vec<(String, String)> ) -> Result<Option<StateChangeRecord>, StorageError>

Get a state change based on data field attributes.

source

pub fn get_state_change_with_balance_proof_by_balance_hash( &self, canonical_identifier: CanonicalIdentifier, balance_hash: H256, recipient: H160 ) -> Result<Option<StateChangeRecord>, StorageError>

Get a state change that contains a balance proof that matches the provided balance_hash.

source

pub fn get_state_change_with_balance_proof_by_locksroot( &self, canonical_identifier: CanonicalIdentifier, locksroot: H256, recipient: H160 ) -> Result<Option<StateChangeRecord>, StorageError>

Get a state change that contains a balance proof that matches the provided locksroot.

source

pub fn get_latest_event_by_data_field( &self, criteria: Vec<(String, String)> ) -> Result<Option<EventRecord>, StorageError>

Get the latest event filtered by criteria of data field attributes.

source

pub fn get_event_with_balance_proof_by_balance_hash( &self, canonical_identifier: CanonicalIdentifier, balance_hash: H256, recipient: H160 ) -> Result<Option<EventRecord>, StorageError>

Get an event with a balance proof filtered by the balance_hash.

source

pub fn get_event_with_balance_proof_by_locksroot( &self, canonical_identifier: CanonicalIdentifier, locksroot: H256, recipient: H160 ) -> Result<Option<EventRecord>, StorageError>

Get an event with a balance proof filtered by the locksroot.

source

pub fn get_events_with_timestamps( &self ) -> Result<Vec<EventRecord>, StorageError>

Return events with timestamps.

source

pub fn get_events_payment_history_with_timestamps( &self, token_network_address: Option<H160>, partner_address: Option<H160> ) -> Result<Vec<EventRecord>, StorageError>

Get events of payments with timestamps attached.