Struct raiden_rs::raiden_network_transport::matrix::MatrixClient
source · pub struct MatrixClient { /* private fields */ }Expand description
Matrix client type.
Implementations
sourceimpl MatrixClient
impl MatrixClient
sourcepub async fn new(
homeserver_url: String,
private_key: PrivateKey
) -> MatrixClient
pub async fn new( homeserver_url: String, private_key: PrivateKey ) -> MatrixClient
Create a new instance of MatrixClient.
sourcepub fn set_sync_token(&mut self, sync_token: String)
pub fn set_sync_token(&mut self, sync_token: String)
Set sync token based on the last sync.
sourcepub fn get_sync_token(&self) -> String
pub fn get_sync_token(&self) -> String
Return the last known sync token.
sourcepub fn private_key(&self) -> PrivateKey
pub fn private_key(&self) -> PrivateKey
Return a copy of the private key.
sourcepub async fn init(&self) -> Result<(), TransportError>
pub async fn init(&self) -> Result<(), TransportError>
Initialize the client by logging into the matrix home server.
sourcepub async fn populate_services_addresses(
&mut self,
service_registry_proxy: ServiceRegistryProxy<Http>
)
pub async fn populate_services_addresses( &mut self, service_registry_proxy: ServiceRegistryProxy<Http> )
Populate services addresses based on on-chain updates to the service registry.
sourcepub async fn get_new_messages(&mut self) -> Result<Vec<IncomingMessage>, Error>
pub async fn get_new_messages(&mut self) -> Result<Vec<IncomingMessage>, Error>
Sync and retrieve any new messages received on the home server.
sourcepub fn address_metadata(&self) -> AddressMetadata
pub fn address_metadata(&self) -> AddressMetadata
Construct the address metadata of the current account.
sourcepub fn make_user_id(&self, address: &H160) -> String
pub fn make_user_id(&self, address: &H160) -> String
Return’s the matrix user ID.
sourcepub async fn send(
&self,
message: OutgoingMessage,
receiver_metadata: AddressMetadata
) -> Result<(), TransportError>
pub async fn send( &self, message: OutgoingMessage, receiver_metadata: AddressMetadata ) -> Result<(), TransportError>
Send message to the matrix home server.
sourcepub async fn broadcast(
&self,
data: String,
device_id: DeviceIdOrAllDevices
) -> Result<(), TransportError>
pub async fn broadcast( &self, data: String, device_id: DeviceIdOrAllDevices ) -> Result<(), TransportError>
Broadcast message to all known service addresses.